/*
 * File Selection - A java utility to browse and manipulate sets of files.
 * Copyright (C) 2013  David I. Bell
 * 
 * This program is free software; you can redistribute it and/or modify
 * it under the terms of the GNU General Public License as published by
 * the Free Software Foundation; either version 2 of the License, or
 * (at your option) any later version.
 * 
 * This program is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 * GNU General Public License for more details.
 * 
 * You should have received a copy of the GNU General Public License
 * along with this program; if not, write to the Free Software
 * Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307  USA
 */
package fileselection.dialog;

import fileselection.ManualSelectList;


/**
 * A simple class to keep track of the action to take when a
 * command has a particular exit status.
 */
public class CommandExitStatusAction
{
	/**
	 * The exit status this information is for.
	 */
	private final int mExitStatus;

	/**
	 * Whether or not the exit status is considered a failure.
	 */
	private final boolean mIsFailure;

	/**
	 * The manual select list to place files in if the command
	 * gives this exit status.  This can be null.
	 */
	private final ManualSelectList mSelectList;

	/**
	 * Whether the select list is to be cleared before running
	 * any commands.
	 */
	private final boolean mIsCleared;


	/**
	 * Constructor to initialise the fields.
	 */
	public CommandExitStatusAction(int exitStatus, boolean isFailure,
		ManualSelectList selectList, boolean isCleared)
	{
		mExitStatus = exitStatus;
		mIsFailure = isFailure;
		mSelectList = selectList;
		mIsCleared = isCleared;
	}


	/**
	 * Return the exit status this information is for.
	 */
	public int getExitStatus()
	{
		return mExitStatus;
	}


	/**
	 * Return the manual select list that files giving this exit
	 * status for a command are put in.  This can be null.
	 */
	public ManualSelectList getSelectList()
	{
		return mSelectList;
	}


	/**
	 * Return whether the select list is to be cleared before any
	 * commands are run.
	 */
	public boolean isCleared()
	{
		return mIsCleared;
	}


	/**
	 * Return whether this exit status is considered a failure.
	 */
	public boolean isFailure()
	{
		return mIsFailure;
	}
}
